/* This example shows how to get single-shot range
 measurements from the VL53L0X. The sensor can optionally be
 configured with different ranging profiles, as described in
 the VL53L0X API user manual, to get better performance for
 a certain application. This code is based on the four
 "SingleRanging" examples in the VL53L0X API.

 The range readings are in units of mm. */

#include <Wire.h>
#include "VL53L0X_x.h"

#define DISTANCE_100	450
#define DISTANCE_0		100
#define SPEEDLIMRATE	100 // 100 or 255


VL53L0X sensor;

//Task Schedule
unsigned long gPreviousL5 = 0;



void setup()
{
	Serial.begin(9600);
	Wire.begin();

	sensor.init();
	sensor.setTimeout(500);

	// Start continuous back-to-back mode (take readings as
	// fast as possible).  To use continuous timed mode
	// instead, provide a desired inter-measurement period in
	// ms (e.g. sensor.startContinuous(100)).
	sensor.startContinuous(100);
	
	
	//Reset task
	gPreviousL5 = millis();

}

void loop()
{
	uint16_t aLimit = 0;
	
	if( (millis() - gPreviousL5) >= 200)
	{
		/* Receive milimeter distance */ 
		uint16_t aDistance = sensor.readRangeContinuousMillimeters();
		
		/* Calculate Distance to Limit speed */
		if( aDistance < DISTANCE_0)
		{
			aLimit = 0;
		}
		else if (aDistance > DISTANCE_100)
		{
			aLimit = SPEEDLIMRATE;
		}
		else
		{
			aLimit = ((aDistance - DISTANCE_0) * SPEEDLIMRATE) / (DISTANCE_100 - DISTANCE_0);
		}
		
		
		/* Display Distance and Speed limit */
		Serial.print(aDistance);
		Serial.print(",");
		Serial.print(aLimit);
		
		if (sensor.timeoutOccurred()) 
		{ 
			Serial.print(" TIMEOUT"); 
		}
		
		Serial.println();
		
	}
	
	
	
	
	
	
	
}